==> openshift-model-console-6.5.1-sources.jar: io/fabric8/openshift/api/model/console/v1/NamespaceDashboardSpecFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NamespaceDashboardSpecFluent<A extends NamespaceDashboardSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildNamespaceSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getNamespaceSelector();
  public LabelSelector buildNamespaceSelector();
  public A withNamespaceSelector(LabelSelector namespaceSelector);
  public Boolean hasNamespaceSelector();
  public NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
  public NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(LabelSelector item);
  public NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> editNamespaceSelector();
  public NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
  public NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(LabelSelector item);
  public A addToNamespaces(Integer index,String item);
  public A setToNamespaces(Integer index,String item);
  public A addToNamespaces(java.lang.String... items);
  public A addAllToNamespaces(Collection<String> items);
  public A removeFromNamespaces(java.lang.String... items);
  public A removeAllFromNamespaces(Collection<String> items);
  public List<String> getNamespaces();
  public String getNamespace(Integer index);
  public String getFirstNamespace();
  public String getLastNamespace();
  public String getMatchingNamespace(Predicate<String> predicate);
  public Boolean hasMatchingNamespace(Predicate<String> predicate);
  public A withNamespaces(List<String> namespaces);
  public A withNamespaces(java.lang.String... namespaces);
  public Boolean hasNamespaces();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface NamespaceSelectorNested<N> extends Nested<N>,LabelSelectorFluent<NamespaceDashboardSpecFluent.NamespaceSelectorNested<N>>{
    public N and();
    public N endNamespaceSelector();
    
  }
  
}

==> openshift-model-console-6.7.2-sources.jar: io/fabric8/openshift/api/model/console/v1/NamespaceDashboardSpecFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NamespaceDashboardSpecFluent<A extends NamespaceDashboardSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildNamespaceSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getNamespaceSelector();
  public LabelSelector buildNamespaceSelector();
  public A withNamespaceSelector(LabelSelector namespaceSelector);
  public Boolean hasNamespaceSelector();
  public NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
  public NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(LabelSelector item);
  public NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> editNamespaceSelector();
  public NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
  public NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(LabelSelector item);
  public A addToNamespaces(int index,String item);
  public A setToNamespaces(int index,String item);
  public A addToNamespaces(java.lang.String... items);
  public A addAllToNamespaces(Collection<String> items);
  public A removeFromNamespaces(java.lang.String... items);
  public A removeAllFromNamespaces(Collection<String> items);
  public List<String> getNamespaces();
  public String getNamespace(int index);
  public String getFirstNamespace();
  public String getLastNamespace();
  public String getMatchingNamespace(Predicate<String> predicate);
  public Boolean hasMatchingNamespace(Predicate<String> predicate);
  public A withNamespaces(List<String> namespaces);
  public A withNamespaces(java.lang.String... namespaces);
  public Boolean hasNamespaces();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface NamespaceSelectorNested<N> extends Nested<N>,LabelSelectorFluent<NamespaceDashboardSpecFluent.NamespaceSelectorNested<N>>{
    public N and();
    public N endNamespaceSelector();
    
  }
  
}
